import argparse
import os
import shutil


def main():
    parser = argparse.ArgumentParser(
        "smoloki-install",
        description="cli for installing wrapper for smoloki",
    )
    parser.add_argument(
        "--install-wrapper-for-nodejs",
        dest="install_wrapper_for_nodejs",
        type=str,
        default="",
        help="path to target node_modules/ folder",
    )

    args = parser.parse_args()

    if args.install_wrapper_for_nodejs:
        source_path = os.path.join(os.path.dirname(__file__), "nodejs.js")
        wrapper_path = os.path.join(args.install_wrapper_for_nodejs, "smoloki.js")
        shutil.copy(source_path, wrapper_path)
        print(f'Installed wrapper for NodeJS: "{wrapper_path}".')


if __name__ == "__main__":
    main()



# -*- coding: utf-8 -*-

import os
import setuptools


assert os.environ.get("GITHUB_REF_TYPE") == "tag"
assert os.environ.get("GITHUB_REF_NAME")
VERSION = os.environ["GITHUB_REF_NAME"]


with open("README.md", "r") as fh:
    long_description = fh.read()


setuptools.setup(
    name="smoloki",
    version=VERSION,
    author="Michael Krukov",
    author_email="krukov.michael@ya.ru",
    keywords=["library", "loki"],
    description="Tiny library to push logs to `Grafana Loki` in `logfmt` format.",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/michaelkryukov/smoloki",
    packages=setuptools.find_packages(),
    install_requires=[
        "aiohttp~=3.8.3",
    ],
    entry_points={
        "console_scripts": [
            "smoloki = smoloki.__main__:main",
            "smoloki-wrappers = smoloki.wrappers:main",
        ],
    },
    package_data={"smoloki": ["wrappers/*.js"]},
    python_requires=">=3.8",
    classifiers=[
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3 :: Only",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
        "Intended Audience :: Developers",
    ],
)



from smoloki import logfmt_load, logfmt_dump

CASES = [
    [{"key": "value"}, "key=value"],
    [{"key": '"value"'}, 'key="\\"value\\""'],
    [{"key": "v=alue"}, 'key="v=alue"'],
    [{"key": "va l ue"}, 'key="va l ue"'],
    [{"key": "va\\l\\ue"}, "key=va\\\\l\\\\ue"],
    [{"key": "va\nl\nue"}, "key=va\\nl\\nue"],
    [{"key": "'"}, "key='"],
    [{"key": '"'}, 'key="\\""'],
]


def test_dump():
    for original_value, dumped_value in CASES:
        assert logfmt_dump(original_value) == dumped_value


def test_dump_int_and_float():
    assert logfmt_dump({"key": 1}) == "key=1"
    assert logfmt_dump({"key": 1.5}) == "key=1.5"


def test_load():
    for original_value, dumped_value in CASES:
        assert logfmt_load(dumped_value) == original_value
